/*****************************************************************************

    TRAVIS - Trajectory Analyzer and Visualizer

    http://www.travis-analyzer.de/

    Copyright (c) 2009-2018 Martin Brehm
                  2012-2018 Martin Thomas
                  2016-2018 Sascha Gehrke

    This file was written by Sascha Gehrke.

    ---------------------------------------------------------------------------

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*****************************************************************************/


#ifndef REFLUX_H
#define REFLUX_H


// This must always be the first include directive
#include "config.h"

#include "moltools.h"


bool gatherReFlux();
bool initializeReFlux();
bool processReFlux(CTimeStep* ts);
bool finalizeReFlux();

class CReFluxCond: public CxObject
{
public:
	CReFluxCond();
	~CReFluxCond();

	int m_iRefNeigh; 		// Reference for neighbor criterion
	int m_iObsNeigh; 		// Observed for neighbor criterion
	double m_dNeighDist;		// Distance for Neighbor

	CxIntArray m_iaRefAggr;		// References for Aggregation
	CxIntArray m_iaObsAggr;		// Observed for Aggregation
	double m_dAggrDist;		// Distance for Aggregation

	CxIntArray m_iaRefVec;		// Reference vectors base for angle crit
	CxIntArray m_iaRefVec2;		// Reference vectors tipp
	CxIntArray m_iaRefVec3;		// only used if Vectors are defined by plane
	CxIntArray m_iaObsVec;		// Observed vectors base for angle crit
	CxIntArray m_iaObsVec2;		// Observed vectors tipp
	CxIntArray m_iaObsVec3;		// only used if Vectors are defined by plane
	double m_dAggrMinAngle;		// Angle for AngleCrit
	double m_dAggrMaxAngle;		// Angle for AngleCrit

	void check(CTimeStep*,CxIntArray*,CxIntArray*);	// checks conditions for fulfillment
	bool angle(CTimeStep*, int, int);	// checks angle criterion
	void Sort();				// Sorts the angles 
};

class CReFluxObservation: public CObservation
{
public:
	CReFluxObservation();
	~CReFluxObservation();

	CxObArray m_oaCond;		// Contains the conditions for the possible pairs

	CxObArray m_oaNeigh;		// Contains the switching timesteps 
	CxObArray m_oaAggr;

	CxDoubleArray AggrDynamic; // Final Datasets after processing
	CxDoubleArray DiffusionDynamic;
	CxDoubleArray k_t; 	// Numerical derivation of BondDynamic
	CxDoubleArray a;		
	CxDoubleArray b;

	int m_iShowMol3;
	bool m_bRefVecPlane;		// defined by plane?
	bool m_bObsVecPlane;		// defined by plane?
	bool m_bLuzar;
	int m_iDepth, m_iTrunc;
	double m_dNeighDist, m_dAggrDist;
	double m_dGraceMin, m_dGraceMax;

	void initialize();
	void process(CTimeStep* ts);
	void finalize();

	bool checkAtomChoice(const char*);
	bool includeAtom(int, int, int, int);
	void RestoreFunction(CxIntArray*, CxDoubleArray*);
	void CalcMinMax();
	void WriteOutput();
	
private:

};


#endif

